# DicerGirl

![PyPI - Python Version](https://img.shields.io/pypi/pyversions/dicergirl)
[![PyPI](https://img.shields.io/pypi/v/dicergirl)](https://pypi.org/project/dicergirl/)
![PyPI - Wheel](https://img.shields.io/pypi/wheel/dicergirl)
[![PyPI - Downloads](https://img.shields.io/pypi/dw/dicergirl)](https://pypi.org/project/dicergirl/)
![PyPI - License](https://img.shields.io/pypi/l/dicergirl)

## 简介

Noctisynth DicerGirl 是新一代跨平台开源 TRPG 骰娘框架, 公测 QQ 群号：[770386358](http://qm.qq.com/cgi-bin/qm/qr?_wv=1027&k=hvaf8JGmEXA3N9r4SGgpghDti31aW1bR&authKey=%2Bux%2BedOIguriMYBMGe40coeOT7mx%2B99%2FVMbK0MvE2w1AsVQLLK%2B0hBO6vVB%2Bmlws&noverify=0&group_code=770386358).

## 文档

前往[DicerGirl 文档](https://dicer.unvisitor.site)。

## 跑团模块系统

|          COC           |          DND           |          SCP           |
| :--------------------: | :--------------------: | :--------------------: |
| `dicergirl-plugin-coc` | `dicergirl-plugin-dnd` | `dicergirl-plugin-scp` |
|           ✅           |           ✅           |           ✅           |

## 特别鸣谢

- [Nonebot2](https://github.com/nonebot/nonebot2/) @[yanyongyu](https://github.com/yanyongyu)
- [go-cqhttp](https://github.com/Mrs4s/go-cqhttp) @[Mrs4s](https://github.com/Mrs4s)
- [nonebot-plugin-cocdicer](https://github.com/abrahum/nonebot_plugin_cocdicer) @[abrahum](https://github.com/abrahum)

## 漏洞或建议提交

如果你对于 DicerGirl 有建议或发现漏洞, 请在[issues](issues)中提交你的建议.

## 发电作者

作者前几天刚弄的[爱发电](https://afdian.net/a/obliviated)，如果你和作者一样穷困潦倒（x），就给这个项目送个 Star 吧！

## 版权声明

此项目以 Apache-2.0 协议开源, 使用代码时, 请注意遵照开源协议.
